@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include <glib.h>
 #include <string.h>
 #include <Carbon/Carbon.h>
@@ -93,14 +93,17 @@ basic_engine_shape (PangoEngineShape    *engine,
 
   utf16 = g_utf8_to_utf16 (text, length, NULL, &n16, NULL);
 
-  err = ATSUCreateTextLayout (&text_layout);
-  err = ATSUSetTextPointerLocation (text_layout, utf16, 0, n16, n16);
+  err = ATSUCreateTextLayoutWithTextPtr (utf16, 0, n16, n16,
+                                         0,
+                                         NULL,
+                                         NULL,
+                                         &text_layout);
 
   err = ATSUCreateStyle(&style);
-  fontID = pango_atsui_font_get_atsu_font_id (afont);
+  fontID = pango_atsui_font_get_atsfont (afont);
 
   err = ATSUSetAttributes(style,
-			  sizeof(styleTags) / sizeof(styleTags[0]),
+			  (ItemCount)(sizeof(styleTags) / sizeof(styleTags[0])),
 			  styleTags, styleSizes, styleValues);
 
   err = ATSUSetRunStyle(text_layout,
