@@ -400,7 +400,7 @@ get_item_properties (PangoItem       *item,
     {
       PangoAttribute *attr = l->data;
 
-      switch (attr->klass->type)
+      switch ((int) attr->klass->type)
 	{
 	case PANGO_ATTR_SHAPE:
 	  if (shape_attr)
@@ -475,11 +475,11 @@ pango_renderer_draw_layout_line (PangoRenderer    *renderer,
    * active.
    */
   if (!renderer->active_count)
-    {
-      PangoContext *context = pango_layout_get_context (line->layout);
-      pango_renderer_set_matrix (renderer,
-				 pango_context_get_matrix (context));
-    }
+    pango_renderer_set_matrix (renderer,
+			       G_LIKELY (line->layout) ?
+			       pango_context_get_matrix
+			       (pango_layout_get_context (line->layout)) :
+			       NULL);
 
   pango_renderer_activate (renderer);
 
@@ -489,7 +489,7 @@ pango_renderer_draw_layout_line (PangoRenderer    *renderer,
   state.underline = PANGO_UNDERLINE_NONE;
   state.strikethrough = FALSE;
 
-  text = pango_layout_get_text (line->layout);
+  text = G_LIKELY (line->layout) ? pango_layout_get_text (line->layout) : NULL;
 
   for (l = line->runs; l; l = l->next)
     {
@@ -676,7 +676,7 @@ pango_renderer_default_draw_glyphs (PangoRenderer    *renderer,
 /**
  * pango_renderer_draw_glyph_item:
  * @renderer: a #PangoRenderer
- * @text: the UTF-8 text that @glyph_item refers to
+ * @text: the UTF-8 text that @glyph_item refers to, or %NULL
  * @glyph_item: a #PangoGlyphItem
  * @x: X position of left edge of baseline, in user space coordinates
  *   in Pango units.
@@ -690,6 +690,8 @@ pango_renderer_default_draw_glyphs (PangoRenderer    *renderer,
  * Note that @text is the start of the text for layout, which is then
  * indexed by <literal>@glyph_item->item->offset</literal>.
  *
+ * If @text is %NULL, this simply calls pango_renderer_draw_glyphs().
+ *
  * The default implementation of this method simply falls back to
  * pango_renderer_draw_glyphs().
  *
@@ -702,6 +704,15 @@ pango_renderer_draw_glyph_item (PangoRenderer    *renderer,
 				int               x,
 				int               y)
 {
+  if (G_UNLIKELY (text))
+    {
+      pango_renderer_draw_glyphs (renderer,
+				  glyph_item->item->analysis.font,
+				  glyph_item->glyphs,
+				  x, y);
+      return;
+    }
+
   g_return_if_fail (PANGO_IS_RENDERER_FAST (renderer));
 
   pango_renderer_activate (renderer);
@@ -975,6 +986,7 @@ pango_renderer_default_draw_error_underline (PangoRenderer *renderer,
   const PangoMatrix *matrix;
   double dx, dx0, dy0;
   PangoMatrix total;
+  int i;
 
   x += (width - width_units * unit_width) / 2;
   width = width_units * unit_width;
@@ -989,27 +1001,25 @@ pango_renderer_default_draw_error_underline (PangoRenderer *renderer,
   dx0 = (matrix->xx * dx) / PANGO_SCALE;
   dy0 = (matrix->yx * dx) / PANGO_SCALE;
 
+  i = (width_units - 1) / 2;
   while (TRUE)
     {
-
       draw_rectangle (renderer, &total, PANGO_RENDER_PART_UNDERLINE, /* A */
 		      0,                      0,
 		      HEIGHT_SQUARES * 2 - 1, 1);
 
-      if (width_units > 2)
-	{
-	  draw_rectangle (renderer, &total, PANGO_RENDER_PART_UNDERLINE, /* B */
-			  HEIGHT_SQUARES * 2 - 2, - (HEIGHT_SQUARES * 2 - 3),
-			  1,                      HEIGHT_SQUARES * 2 - 3);
-	  width_units -= 2;
+      if (i <= 0)
+        break;
+      i--;
 
-	  total.x0 += dx0;
-	  total.y0 += dy0;
-	}
-      else
-	break;
+      draw_rectangle (renderer, &total, PANGO_RENDER_PART_UNDERLINE, /* B */
+		      HEIGHT_SQUARES * 2 - 2, - (HEIGHT_SQUARES * 2 - 3),
+		      1,                      HEIGHT_SQUARES * 2 - 3);
+
+      total.x0 += dx0;
+      total.y0 += dy0;
     }
-  if (width_units == 2)
+  if (width_units % 2 == 0)
     {
       draw_rectangle (renderer, &total, PANGO_RENDER_PART_UNDERLINE, /* C */
 		      HEIGHT_SQUARES * 2 - 2, - (HEIGHT_SQUARES * 2 - 2),
@@ -1265,7 +1275,7 @@ pango_renderer_default_prepare_run (PangoRenderer  *renderer,
     {
       PangoAttribute *attr = l->data;
 
-      switch (attr->klass->type)
+      switch ((int) attr->klass->type)
 	{
 	case PANGO_ATTR_UNDERLINE:
 	  renderer->underline = ((PangoAttrInt *)attr)->value;
@@ -1324,13 +1334,8 @@ pango_renderer_set_matrix (PangoRenderer     *renderer,
 {
   g_return_if_fail (PANGO_IS_RENDERER_FAST (renderer));
 
-  if (renderer->matrix)
-    pango_matrix_free (renderer->matrix);
-  if (matrix)
-    renderer->matrix = pango_matrix_copy (matrix);
-  else
-    renderer->matrix = NULL;
-
+  pango_matrix_free (renderer->matrix);
+  renderer->matrix = pango_matrix_copy (matrix);
 }
 
 /**
@@ -1372,7 +1377,7 @@ pango_renderer_get_matrix (PangoRenderer *renderer)
  * Since: 1.20
  **/
 PangoLayout *
-pango_renderer_get_layout      (PangoRenderer     *renderer)
+pango_renderer_get_layout (PangoRenderer *renderer)
 {
   if (G_UNLIKELY (renderer->priv->line == NULL))
     return NULL;
