@@ -1209,6 +1209,7 @@ pango_fc_font_map_add (PangoFcFontMap *fcfontmap,
 }
 
 /* Remove mapping from fcfont->key to fcfont */
+/* Closely related to shutdown_font() */
 void
 _pango_fc_font_map_remove (PangoFcFontMap *fcfontmap,
 			   PangoFcFont    *fcfont)
@@ -1809,7 +1810,7 @@ pango_fc_font_map_get_font_face_data (PangoFcFontMap *fcfontmap,
   return data;
 }
 
-PangoFcCmapCache *
+static PangoFcCmapCache *
 _pango_fc_cmap_cache_ref (PangoFcCmapCache *cmap_cache)
 {
   g_atomic_int_inc ((int *) &cmap_cache->ref_count);
@@ -1834,7 +1835,6 @@ _pango_fc_font_map_get_cmap_cache (PangoFcFontMap *fcfontmap,
 {
   PangoFcFontMapPrivate *priv;
   PangoFcFontFaceData *data;
-  PangoFcCmapCache *cmap_cache;
 
   if (G_UNLIKELY (fcfontmap == NULL))
 	return NULL;
@@ -1864,9 +1864,7 @@ PangoCoverage *
 _pango_fc_font_map_get_coverage (PangoFcFontMap *fcfontmap,
 				 PangoFcFont    *fcfont)
 {
-  PangoFcFontMapPrivate *priv = fcfontmap->priv;
   PangoFcFontFaceData *data;
-  PangoCoverage *coverage;
   FcCharSet *charset;
 
   if (G_UNLIKELY (!fcfont->font_pattern))
@@ -1974,16 +1972,14 @@ pango_fc_font_map_create_context (PangoFcFontMap *fcfontmap)
 }
 
 static void
-shutdown_font (gpointer        key G_GNUC_UNUSED,
+shutdown_font (gpointer        key,
 	       PangoFcFont    *fcfont,
 	       PangoFcFontMap *fcfontmap)
 {
   _pango_fc_font_shutdown (fcfont);
 
-  /* While _pango_fc_font_shutdown() tries to call the following
-   * function, it's too late as the fontmap weakref has already
-   * NULL'ed fcfont->fontmap, so we do it ourselves. */
-  _pango_fc_font_map_remove (fcfontmap, fcfont);
+  _pango_fc_font_set_font_key (fcfont, NULL);
+  pango_fc_font_key_free (key);
 }
 
 /**
